==> create-fly-1.21.8-6.0.8-2-sources.jar: com/zurrtum/create/foundation/advancement/CreateTrigger.java <==
package com.zurrtum.create.foundation.advancement;

import com.google.common.collect.Maps;
import com.mojang.serialization.Codec;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;
import net.minecraft.class_179;
import net.minecraft.class_184;
import net.minecraft.class_2960;
import net.minecraft.class_2985;
import net.minecraft.class_3222;
import net.minecraft.class_8944;

public class CreateTrigger implements class_179<CreateTrigger.Conditions> {
    public final Map<class_2985, Set<class_180<Conditions>>> listeners = Maps.newHashMap();
    public final class_2960 id;

    public CreateTrigger(class_2960 id) {
        this.id = id;
    }

    @Override
    public void method_792(class_2985 playerAdvancementsIn, class_180<Conditions> listener) {
        listeners.computeIfAbsent(playerAdvancementsIn, k -> new HashSet<>()).add(listener);
    }

    @Override
    public void method_793(class_2985 playerAdvancementsIn, class_180<Conditions> listener) {
        Set<class_180<Conditions>> playerListeners = this.listeners.get(playerAdvancementsIn);
        if (playerListeners != null) {
            playerListeners.remove(listener);
            if (playerListeners.isEmpty()) {
                this.listeners.remove(playerAdvancementsIn);
            }
        }
    }

    @Override
    public void method_791(class_2985 playerAdvancementsIn) {
        this.listeners.remove(playerAdvancementsIn);
    }

    @Override
    public Codec<Conditions> method_54937() {
        return Conditions.CODEC;
    }

    public void trigger(class_3222 player) {
        class_2985 playerAdvancements = player.method_14236();
        Set<class_180<Conditions>> playerListeners = this.listeners.get(playerAdvancements);
        if (playerListeners != null) {
            for (class_180<Conditions> listener : playerListeners) {
                listener.method_796(playerAdvancements);
            }
        }
    }

    public static class Conditions implements class_184 {
        public static final Codec<Conditions> CODEC = Codec.unit(new Conditions());

        @Override
        public void method_54938(class_8944 validator) {
        }
    }
}

==> create-fly-1.21.11-6.0.8-2-sources.jar: com/zurrtum/create/foundation/advancement/CreateTrigger.java <==
package com.zurrtum.create.foundation.advancement;

import com.google.common.collect.Maps;
import com.mojang.serialization.Codec;
import com.mojang.serialization.MapCodec;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;
import net.minecraft.class_179;
import net.minecraft.class_184;
import net.minecraft.class_2960;
import net.minecraft.class_2985;
import net.minecraft.class_3222;
import net.minecraft.class_8944;

public class CreateTrigger implements class_179<CreateTrigger.Conditions> {
    public final Map<class_2985, Set<class_180<Conditions>>> listeners = Maps.newHashMap();
    public final class_2960 id;

    public CreateTrigger(class_2960 id) {
        this.id = id;
    }

    @Override
    public void method_792(class_2985 playerAdvancementsIn, class_180<Conditions> listener) {
        listeners.computeIfAbsent(playerAdvancementsIn, k -> new HashSet<>()).add(listener);
    }

    @Override
    public void method_793(class_2985 playerAdvancementsIn, class_180<Conditions> listener) {
        Set<class_180<Conditions>> playerListeners = this.listeners.get(playerAdvancementsIn);
        if (playerListeners != null) {
            playerListeners.remove(listener);
            if (playerListeners.isEmpty()) {
                this.listeners.remove(playerAdvancementsIn);
            }
        }
    }

    @Override
    public void method_791(class_2985 playerAdvancementsIn) {
        this.listeners.remove(playerAdvancementsIn);
    }

    @Override
    public Codec<Conditions> method_54937() {
        return Conditions.CODEC;
    }

    public void trigger(class_3222 player) {
        class_2985 playerAdvancements = player.method_14236();
        Set<class_180<Conditions>> playerListeners = this.listeners.get(playerAdvancements);
        if (playerListeners != null) {
            for (class_180<Conditions> listener : playerListeners) {
                listener.method_796(playerAdvancements);
            }
        }
    }

    public static class Conditions implements class_184 {
        public static final Codec<Conditions> CODEC = MapCodec.unitCodec(new Conditions());

        @Override
        public void method_54938(class_8944 validator) {
        }
    }
}
